@@ -1798,6 +1798,7 @@ ResourceTypeType = Literal[
     "verified-access-trust-provider",
     "volume",
     "vpc",
+    "vpc-block-public-access-exclusion",
     "vpc-endpoint",
     "vpc-endpoint-connection",
     "vpc-endpoint-connection-device-type",
@@ -2277,6 +2278,7 @@ ServiceName = Literal[
     "sagemaker-edge",
     "sagemaker-featurestore-runtime",
     "sagemaker-geospatial",
+    "sagemaker-metrics",
     "sagemaker-runtime",
     "savingsplans",
     "scheduler",
